@@ -5,8 +5,8 @@ from typing import Iterator, Tuple
 from pysubparser.classes.exceptions import InvalidTimestampError
 from pysubparser.classes.subtitle import Subtitle
 
-TIMESTAMP_SEPARATOR = ' --> '
-TIMESTAMP_FORMAT = '%H:%M:%S,%f'
+TIMESTAMP_SEPARATOR = " --> "
+TIMESTAMP_FORMAT = "%H:%M:%S,%f"
 
 
 def parse_timestamps(line: str) -> Tuple[time, time]:
@@ -18,14 +18,10 @@ def parse_timestamps(line: str) -> Tuple[time, time]:
 
         return start, end
     except ValueError:
-        raise InvalidTimestampError(line, TIMESTAMP_FORMAT, 'srt')
+        raise InvalidTimestampError(line, TIMESTAMP_FORMAT, "srt")
 
 
-def parse(
-        path: str,
-        encoding: str = "utf-8",
-        **_
-) -> Iterator[Subtitle]:
+def parse(path: str, encoding: str = "utf-8", **_) -> Iterator[Subtitle]:
     index = count(0)
 
     with open(path, encoding=encoding) as file:
@@ -45,4 +41,3 @@ def parse(
                 else:
                     yield subtitle
                     subtitle = None
-
